@@ -49,7 +49,7 @@ class CreateTokenQuery(StaticQuery):  # pylint:disable=too-few-public-methods
     ):  # pylint:disable=arguments-differ
         return {"username": username, "password": password}
 
-    def _format_response(self, response: dict) -> Tuple[str, str]:
+    def _format_response(self, response: dict, *_) -> Tuple[str, str]:
         token_obj = response["createToken"]["token"]
         access_token = token_obj["access"]
         refresh_token = token_obj["refresh"]
